(*
  Copyright 2010 Gerd Stolpmann

  This file is part of Plasma, a distributed filesystem and a
  map/reduce computation framework. Unless you have a written license
  agreement with the copyright holder (Gerd Stolpmann), the following
  terms apply:

  Plasma is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Plasma is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

*)
(* $Id: mr_test.ml 239 2010-06-23 16:49:03Z gerd $ *)

(* Test program where map and reduce are identity functions *)

let job : Mapred_def.mapred_job =
  let partitions = 16 in
object
  method name = "test1"
  method input_dir = "/input"
  method output_dir = "/output"
  method work_dir = "/work"
  method check_config _ = ()
  method map me id r w =
    try
      while true do
	let r = r#input_record() in
	w # output_record r
      done
    with End_of_file ->
      w # flush()
  method map_tasks = 16
  method sort_limit = 134217728L (* 128 M *)  (* 67108864L (* 64 M *) *)
  method merge_limit = 8
  method split_limit = 4
  method extract_key me line = Mapred_split.tab_split_key line
  method partitions = partitions
  method partition_of_key me key = (Hashtbl.hash key) mod partitions
  method reduce me p r w =
    try
      while true do
	let r = r#input_record() in
	w # output_record r
      done
    with End_of_file ->
      w # flush()
end

let () =
  Mapred_main.main job
